@@ -31,28 +31,13 @@
 #include "eel-lib-self-check-functions.h"
 #include <gtk/gtk.h>
 #include <eel/eel-canvas.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
 # include <cairo-xlib.h>
-#endif
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 #include <math.h>
 #include <stdio.h>
 #include <libcaja-private/caja-global-preferences.h>
 
-#if !GTK_CHECK_VERSION(3, 0, 0)
-#define cairo_surface_t         GdkPixmap
-#define cairo_surface_destroy   g_object_unref
-#define cairo_xlib_surface_get_display  GDK_PIXMAP_XDISPLAY
-#define cairo_xlib_surface_get_drawable GDK_PIXMAP_XID
-#define cairo_set_source_surface gdk_cairo_set_source_pixmap
-#define mate_bg_create_surface              mate_bg_create_pixmap
-#define mate_bg_set_surface_as_root         mate_bg_set_pixmap_as_root
-#define mate_bg_get_surface_from_root       mate_bg_get_pixmap_from_root
-#define mate_bg_crossfade_set_start_surface mate_bg_crossfade_set_start_pixmap
-#define mate_bg_crossfade_set_end_surface   mate_bg_crossfade_set_end_pixmap
-#endif
-
 G_DEFINE_TYPE (EelBackground, eel_background, G_TYPE_OBJECT);
 
 enum
@@ -68,7 +53,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 struct EelBackgroundDetails
 {
     GtkWidget *widget;
-    GtkWidget *front_widget;
     MateBG *bg;
     char *color;
 
@@ -78,12 +62,7 @@ struct EelBackgroundDetails
     MateBGCrossfade *fade;
     int bg_entire_width;
     int bg_entire_height;
-#if GTK_CHECK_VERSION (3, 0, 0)
     GdkRGBA default_color;
-#else
-    GdkColor default_color;
-#endif
-
     gboolean use_base;
 
     /* Is this background attached to desktop window */
@@ -100,10 +79,6 @@ struct EelBackgroundDetails
     gboolean is_active;
 };
 
-#if GTK_CHECK_VERSION (3, 22, 0)
-static GList *desktop_bg_objects = NULL;
-#endif
-
 static void
 free_fade (EelBackground *self)
 {
@@ -149,16 +124,9 @@ eel_background_finalize (GObject *object)
     }
 
     free_background_surface (self);
+
     free_fade (self);
 
-#if GTK_CHECK_VERSION (3, 22, 0)
-    if (self->details->is_desktop)
-    {
-        desktop_bg_objects = g_list_remove (desktop_bg_objects,
-                                            G_OBJECT (self));
-    }
-
-#endif
     G_OBJECT_CLASS (eel_background_parent_class)->finalize (object);
 }
 
@@ -169,38 +137,20 @@ eel_background_unrealize (EelBackground *self)
 
     self->details->bg_entire_width = 0;
     self->details->bg_entire_height = 0;
-#if GTK_CHECK_VERSION (3, 0, 0)
-    self->details->default_color.red = 1.0;
-    self->details->default_color.green = 1.0;
-    self->details->default_color.blue = 1.0;
-    self->details->default_color.alpha = 1.0;
-#else
     self->details->default_color.red = 0xffff;
     self->details->default_color.green = 0xffff;
     self->details->default_color.blue = 0xffff;
-#endif
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define CLAMP_COLOR(v) (CLAMP ((v), 0, 1))
-#else
 #define CLAMP_COLOR(v) (t = (v), CLAMP (t, 0, G_MAXUSHORT))
-#endif
-
 #define SATURATE(v) ((1.0 - saturation) * intensity + saturation * (v))
 
 static void
 make_color_inactive (EelBackground *self,
-#if GTK_CHECK_VERSION (3, 0, 0)
 		     GdkRGBA      *color)
-#else
-		     GdkColor      *color)
-#endif
 {
     double intensity, saturation;
-#if !GTK_CHECK_VERSION (3, 0, 0)
     gushort t;
-#endif
 
     if (!self->details->is_active) {
         saturation = 0.7;
@@ -209,11 +159,7 @@ make_color_inactive (EelBackground *self,
         color->green = SATURATE (color->green);
         color->blue = SATURATE (color->blue);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-        if (intensity > 0.5)
-#else
         if (intensity > G_MAXUSHORT / 2)
-#endif
         {
            color->red *= 0.9;
            color->green *= 0.9;
@@ -236,11 +182,7 @@ gchar *
 eel_bg_get_desktop_color (EelBackground *self)
 {
     MateBGColorType type;
-#if GTK_CHECK_VERSION (3, 0, 0)
     GdkRGBA    primary, secondary;
-#else
-    GdkColor   primary, secondary;
-#endif
     char      *start_color, *end_color, *color_spec;
     gboolean   use_gradient = TRUE;
     gboolean   is_horizontal = FALSE;
@@ -260,19 +202,11 @@ eel_bg_get_desktop_color (EelBackground *self)
         use_gradient = FALSE;
     }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     start_color = eel_gdk_rgb_to_color_spec (eel_gdk_rgba_to_rgb (&primary));
 
     if (use_gradient)
     {
         end_color  = eel_gdk_rgb_to_color_spec (eel_gdk_rgba_to_rgb (&secondary));
-#else
-    start_color = eel_gdk_rgb_to_color_spec (eel_gdk_color_to_rgb (&primary));
-
-    if (use_gradient)
-    {
-        end_color  = eel_gdk_rgb_to_color_spec (eel_gdk_color_to_rgb (&secondary));
-#endif
         color_spec = eel_gradient_new (start_color, end_color, is_horizontal);
         g_free (end_color);
     }
@@ -285,7 +219,6 @@ eel_bg_get_desktop_color (EelBackground *self)
     return color_spec;
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void
 set_image_properties (EelBackground *self)
 {
@@ -328,51 +261,6 @@ set_image_properties (EelBackground *self)
         }
     }
 }
-#else
-static void
-set_image_properties (EelBackground *self)
-{
-    GdkColor c;
-
-    if (self->details->is_desktop && !self->details->color)
-        self->details->color = eel_bg_get_desktop_color (self);
-
-    if (!self->details->color)
-    {
-        c = self->details->default_color;
-        make_color_inactive (self, &c);
-        mate_bg_set_color (self->details->bg, MATE_BG_COLOR_SOLID, &c, NULL);
-    }
-    else if (!eel_gradient_is_gradient (self->details->color))
-    {
-        eel_gdk_color_parse_with_white_default (self->details->color, &c);
-        make_color_inactive (self, &c);
-        mate_bg_set_color (self->details->bg, MATE_BG_COLOR_SOLID, &c, NULL);
-    }
-    else
-    {
-        GdkColor c1, c2;
-        char *spec;
-
-        spec = eel_gradient_get_start_color_spec (self->details->color);
-        eel_gdk_color_parse_with_white_default (spec, &c1);
-        make_color_inactive (self, &c1);
-        g_free (spec);
-
-        spec = eel_gradient_get_end_color_spec (self->details->color);
-        eel_gdk_color_parse_with_white_default (spec, &c2);
-        make_color_inactive (self, &c2);
-        g_free (spec);
-
-        if (eel_gradient_is_horizontal (self->details->color)) {
-            mate_bg_set_color (self->details->bg, MATE_BG_COLOR_H_GRADIENT, &c1, &c2);
-        } else {
-            mate_bg_set_color (self->details->bg, MATE_BG_COLOR_V_GRADIENT, &c1, &c2);
-        }
-    }
-}
-#endif
-
 
 gchar *
 eel_background_get_color (EelBackground *self)
@@ -428,7 +316,6 @@ eel_background_ensure_realized (EelBackground *self)
 {
     int width, height;
     GdkWindow *window;
-#if GTK_CHECK_VERSION (3, 0, 0)
     GtkStyleContext *style;
 
     /* Set the default color */
@@ -442,17 +329,6 @@ eel_background_ensure_realized (EelBackground *self)
                                             gtk_style_context_get_state (style),
                                             &self->details->default_color);
     gtk_style_context_restore (style);
-#else
-    GtkStyle *style;
-
-    /* Set the default color */
-    style = gtk_widget_get_style (self->details->widget);
-    if (self->details->use_base) {
-       self->details->default_color = style->base[GTK_STATE_NORMAL];
-    } else {
-        self->details->default_color = style->bg[GTK_STATE_NORMAL];
-    }
-#endif
 
     /* If the window size is the same as last time, don't update */
     drawable_get_adjusted_size (self, &width, &height);
@@ -482,19 +358,11 @@ void
 eel_background_draw (GtkWidget *widget,
                      cairo_t   *cr)
 {
-    EelBackground *self = eel_get_widget_background (widget);
-#if GTK_CHECK_VERSION (3, 0, 0)
-    GdkRGBA color;
-#else
-    GdkColor color;
-#endif
     int width, height;
+    GdkWindow *window = gtk_widget_get_window (widget);
+    GdkRGBA color;
 
-    if (self->details->fade != NULL &&
-        mate_bg_crossfade_is_started (self->details->fade))
-    {
-        return;
-    }
+    EelBackground *self = eel_get_widget_background (widget);
 
     drawable_get_adjusted_size (self, &width, &height);
 
@@ -504,16 +372,11 @@ eel_background_draw (GtkWidget *widget,
 
     cairo_save (cr);
 
-    if (self->details->bg_surface != NULL)
-    {
+    if (self->details->bg_surface != NULL) {
         cairo_set_source_surface (cr, self->details->bg_surface, 0, 0);
         cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
     } else {
-#if GTK_CHECK_VERSION (3, 0, 0)
         gdk_cairo_set_source_rgba (cr, &color);
-#else
-        gdk_cairo_set_source_color (cr, &color);
-#endif
     }
 
     cairo_rectangle (cr, 0, 0, width, height);
@@ -605,7 +468,7 @@ on_fade_finished (MateBGCrossfade *fade,
 
 static gboolean
 fade_to_surface (EelBackground   *self,
-                 GtkWidget       *widget,
+                 GdkWindow       *window,
                  cairo_surface_t *surface)
 {
     if (self->details->fade == NULL ||
@@ -616,22 +479,7 @@ fade_to_surface (EelBackground   *self,
 
     if (!mate_bg_crossfade_is_started (self->details->fade))
     {
-#if GTK_CHECK_VERSION (3, 22, 0)
-        mate_bg_crossfade_start_widget (self->details->fade, widget);
-#else
-        GdkWindow *window;
-
-        if (EEL_IS_CANVAS (widget))
-        {
-            window = gtk_layout_get_bin_window (GTK_LAYOUT (widget));
-        }
-        else
-        {
-            window = gtk_widget_get_window (widget);
-        }
-
         mate_bg_crossfade_start (self->details->fade, window);
-#endif
         if (self->details->is_desktop)
         {
             g_signal_connect (self->details->fade,
@@ -646,70 +494,51 @@ fade_to_surface (EelBackground   *self,
 static void
 eel_background_set_up_widget (EelBackground *self)
 {
+    GdkWindow *window;
     GtkWidget *widget = self->details->widget;
+    GdkRGBA color;
+
     gboolean in_fade = FALSE;
 
     if (!gtk_widget_get_realized (widget))
         return;
 
     eel_background_ensure_realized (self);
+    color = self->details->default_color;
+    make_color_inactive (self, &color);
 
     if (self->details->bg_surface == NULL)
         return;
 
-    gtk_widget_queue_draw (widget);
+    if (EEL_IS_CANVAS (widget)) {
+        window = gtk_layout_get_bin_window (GTK_LAYOUT (widget));
+    } else {
+        window = gtk_widget_get_window (widget);
+    }
 
     if (self->details->fade != NULL)
-        in_fade = fade_to_surface (self, widget, self->details->bg_surface);
+        in_fade = fade_to_surface (self, window, self->details->bg_surface);
 
     if (!in_fade)
     {
-        GdkWindow *window;
+        cairo_pattern_t *pattern;
+        pattern = cairo_pattern_create_for_surface (self->details->bg_surface);
+        gdk_window_set_background_pattern (window, pattern);
+        cairo_pattern_destroy (pattern);
 
-        if (EEL_IS_CANVAS (widget))
-        {
-            window = gtk_layout_get_bin_window (GTK_LAYOUT (widget));
-        }
-        else
-        {
-            window = gtk_widget_get_window (widget);
-        }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        if (self->details->bg_surface != NULL)
-        {
-            gdk_window_set_back_pixmap (window,
-                                        self->details->bg_surface, FALSE);
-        }
-        else
-        {
-            GdkColor color = self->details->default_color;
-            make_color_inactive (self, &color);
-            gdk_window_set_background (window, &color);
-        }
-        gdk_window_invalidate_rect (window, NULL, TRUE);
-
-#endif
         if (self->details->is_desktop)
         {
-#if GTK_CHECK_VERSION (3, 0, 0) && !GTK_CHECK_VERSION (3, 22, 0)
-            if (self->details->bg_surface != NULL)
-            {
-                cairo_pattern_t *pattern =
-                  cairo_pattern_create_for_surface (self->details->bg_surface);
-                gdk_window_set_background_pattern (window, pattern);
-                cairo_pattern_destroy (pattern);
-            }
-            else
-            {
-                GdkRGBA color = self->details->default_color;
-                make_color_inactive (self, &color);
-                gdk_window_set_background_rgba (window, &color);
-            }
-            gdk_window_invalidate_rect (window, NULL, TRUE);
-#endif
             set_root_surface (self, window, gtk_widget_get_screen (widget));
         }
+        else
+        {
+
+            gdk_window_set_background_rgba (window, &color);
+
+        }
+
+        gdk_window_invalidate_rect (window, NULL, TRUE);
     }
 }
 
@@ -724,6 +553,8 @@ background_changed_cb (EelBackground *self)
     eel_background_unrealize (self);
     eel_background_set_up_widget (self);
 
+    gtk_widget_queue_draw (self->details->widget);
+
     return FALSE;
 }
 
@@ -746,13 +577,6 @@ widget_queue_background_change (GtkWidget *widget,
  * EelBackgroundStyle so that it will match the chosen GTK+ theme.
  */
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
-widget_style_updated_cb (GtkWidget *widget,
-                         gpointer   user_data)
-{
-    widget_queue_background_change (widget, user_data);
-}
-#else
 widget_style_set_cb (GtkWidget *widget,
                      GtkStyle  *previous_style,
                      gpointer   user_data)
@@ -760,7 +584,6 @@ widget_style_set_cb (GtkWidget *widget,
     if (previous_style != NULL)
         widget_queue_background_change (widget, user_data);
 }
-#endif
 
 static void
 eel_background_changed (MateBG *bg,
@@ -869,9 +692,7 @@ on_widget_destroyed (GtkWidget *widget,
     }
 
     free_fade (self);
-
     self->details->widget = NULL;
-    self->details->front_widget = NULL;
 }
 
 /* Gets the background attached to a widget.
@@ -880,9 +701,9 @@ on_widget_destroyed (GtkWidget *widget,
    this will create one. To change the widget's background, you can
    just call eel_background methods on the widget.
 
-   If the widget is a desktop window, nothing more needs to be done, otherwise
-   you need to call eel_background_draw() from your draw/expose event handler
-   to draw the background.
+   If the widget is a canvas, nothing more needs to be done.  For
+   normal widgets, you need to call eel_background_draw() from your
+   draw/expose handler to draw the background.
 
    Later, we might want a call to find out if we already have a background,
    or a way to share the same background among multiple widgets; both would
@@ -891,41 +712,22 @@ on_widget_destroyed (GtkWidget *widget,
 EelBackground *
 eel_get_widget_background (GtkWidget *widget)
 {
-    EelBackground *self;
-    gpointer data;
-#if GTK_CHECK_VERSION (3, 22, 0)
-    GList *l;
-#endif
 
     g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
     /* Check for an existing background. */
-    data = g_object_get_data (G_OBJECT (widget), "eel_background");
+    gpointer data = g_object_get_data (G_OBJECT (widget), "eel_background");
     if (data != NULL)
     {
         g_assert (EEL_IS_BACKGROUND (data));
         return data;
     }
-#if GTK_CHECK_VERSION (3, 22, 0)
-    /* Check for an existing desktop window background. */
-    for (l = desktop_bg_objects; l != NULL; l = l->next)
-    {
-        g_assert (EEL_IS_BACKGROUND (l->data));
-        self = EEL_BACKGROUND (l->data);
-        if (widget == self->details->widget)
-        {
-            return self;
-        }
-    }
-#endif
-
-    self = eel_background_new ();
-    self->details->widget = widget;
-    self->details->front_widget = widget;
 
     /* Store the background in the widget's data. */
+    EelBackground *self = eel_background_new ();
     g_object_set_data_full (G_OBJECT (widget), "eel_background",
                             self, g_object_unref);
+    self->details->widget = widget;
 
     g_signal_connect_object (widget, "destroy",
                              G_CALLBACK (on_widget_destroyed), self, 0);
@@ -934,13 +736,8 @@ eel_get_widget_background (GtkWidget *widget)
     g_signal_connect_object (widget, "unrealize",
                              G_CALLBACK (widget_unrealize_cb), self, 0);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-    g_signal_connect_object (widget, "style-updated",
-                             G_CALLBACK (widget_style_updated_cb), self, 0);
-#else
     g_signal_connect_object (widget, "style_set",
                              G_CALLBACK (widget_style_set_cb), self, 0);
-#endif
 
     /* Arrange to get the signal whenever the background changes. */
     g_signal_connect_object (self, "appearance_changed",
@@ -988,16 +785,9 @@ eel_background_init (EelBackground *self)
         			       EelBackgroundDetails);
 
     self->details->bg = mate_bg_new ();
-#if GTK_CHECK_VERSION (3, 0, 0)
-    self->details->default_color.red = 1.0;
-    self->details->default_color.green = 1.0;
-    self->details->default_color.blue = 1.0;
-    self->details->default_color.alpha = 1.0;
-#else
     self->details->default_color.red = 0xffff;
     self->details->default_color.green = 0xffff;
     self->details->default_color.blue = 0xffff;
-#endif
     self->details->is_active = TRUE;
 
     g_signal_connect (self->details->bg, "changed",
@@ -1037,32 +827,14 @@ eel_background_reset (EelBackground *self)
 
 void
 eel_background_set_desktop (EelBackground *self,
+                            GtkWidget     *widget,
                             gboolean       is_desktop)
 {
     self->details->is_desktop = is_desktop;
 
-    if (is_desktop)
+    if (gtk_widget_get_realized (widget) && is_desktop)
     {
-#if GTK_CHECK_VERSION (3, 22, 0)
-        self->details->widget =
-          gtk_widget_get_toplevel (self->details->front_widget);
-
-        desktop_bg_objects = g_list_prepend (desktop_bg_objects,
-                                             G_OBJECT (self));
-
-#endif
-        if (gtk_widget_get_realized (self->details->widget))
-        {
-            widget_realized_setup (self->details->widget, self);
-        }
-    }
-    else
-    {
-#if GTK_CHECK_VERSION (3, 22, 0)
-        desktop_bg_objects = g_list_remove (desktop_bg_objects,
-                                            G_OBJECT (self));
-        self->details->widget = self->details->front_widget;
-#endif
+        widget_realized_setup (widget, self);
     }
 }
 
@@ -1080,7 +852,6 @@ eel_background_set_active (EelBackground *self,
     {
         self->details->is_active = is_active;
         set_image_properties (self);
-        gtk_widget_queue_draw (self->details->widget);
     }
 }
 
@@ -1259,21 +1030,16 @@ eel_background_set_dropped_color (EelBackground *self,
     top_border = 32;
     bottom_border = allocation.height - 32;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     /* If a custom background color isn't set, get the GtkStyleContext's bg color. */
-#else
-    /* If a custom background color isn't set, get the GtkStyle's bg color. */
-#endif
+
     if (!self->details->color)
     {
-#if GTK_CHECK_VERSION (3, 0, 0)
+
         GtkStyleContext *style = gtk_widget_get_style_context (widget);
         GdkRGBA bg;
         gtk_style_context_get_background_color (style, GTK_STATE_FLAG_NORMAL, &bg);
         gradient_spec = gdk_rgba_to_string (&bg);
-#else
-        gradient_spec = gdk_color_to_string (&gtk_widget_get_style (widget)->bg[GTK_STATE_NORMAL]);
-#endif
+
     }
     else
     {
