@@ -95,11 +95,7 @@ gboolean                    eel_background_is_set                (EelBackground
 
 /* Helper function for widgets using EelBackground */
 void                        eel_background_draw                  (GtkWidget       *widget,
-#if GTK_CHECK_VERSION (3, 0, 0)
         							  cairo_t         *cr);
-#else
-        							  GdkEventExpose  *event);
-#endif
 
 /* Handles a dragged color being dropped on a widget to change the background color. */
 void                        eel_background_set_dropped_color     (EelBackground   *self,
