@@ -33,7 +33,6 @@
 #include "caja-location-bar.h"
 #include "caja-search-bar.h"
 #include "caja-pathbar.h"
-#include "caja-main.h"
 #include "caja-window-private.h"
 #include "caja-window-slot.h"
 #include "caja-navigation-window-slot.h"
@@ -601,7 +600,6 @@ caja_window_slot_open_location_full (CajaWindowSlot *slot,
     } else if (target_navigation) {
         target_window = caja_application_create_navigation_window
             (window->application,
-             NULL,
              gtk_window_get_screen (GTK_WINDOW (window)));
     } else {
         target_window = caja_application_get_spatial_window
@@ -1195,7 +1193,7 @@ got_file_info_for_view_selection_callback (CajaFile *file,
     GFile *location;
     GMountOperation *mount_op;
     MountNotMountedData *data;
-
+    CajaApplication *app;
     slot = callback_data;
     g_assert (CAJA_IS_WINDOW_SLOT (slot));
     g_assert (slot->determine_view_file == file);
@@ -1308,9 +1306,9 @@ got_file_info_for_view_selection_callback (CajaFile *file,
              * happens when a new window cannot display its initial URI.
              */
             /* if this is the only window, we don't want to quit, so we redirect it to home */
-            if (caja_application_get_n_windows () <= 1)
-            {
-                g_assert (caja_application_get_n_windows () == 1);
+            app = CAJA_APPLICATION (g_application_get_default ());
+			
+            if (g_list_length (gtk_application_get_windows (GTK_APPLICATION (app))) == 1) {
 
                 /* the user could have typed in a home directory that doesn't exist,
                    in which case going home would cause an infinite loop, so we
